-------------------------------------------------------------------------------
-- Title      :  IEEE format incoding core
-- Project    :  Floating-Point Unit core
-------------------------------------------------------------------------------
-- File        : encode.vhd
-- Author      : Jamil Khatib  (khatib@ieee.org)
-- Organization: OpenIPCore Project
-- Created     : 2000/12/12
-- Last update : 2000/12/12
-- Platform    : 
-- Simulators  : Modelsim 5.3XE/Windows98
-- Synthesizers: Leonardo/WindowsNT
-- Target      : 
-- Dependency  : ieee.std_logic_1164
--               utility.tools_pkg
--               fpu.fpu_pkg
-------------------------------------------------------------------------------
-- Description: IEEE format encoder core
-------------------------------------------------------------------------------
-- Copyright (c) 2000 Jamil Khatib
-- 
-- This VHDL design file is an open design; you can redistribute it and/or
-- modify it and/or implement it after contacting the author
-- You can check the draft license at
-- http://www.opencores.org/OIPC/license.shtml

-------------------------------------------------------------------------------
-- Revisions  :
-- Revision Number :   1
-- Version         :   0.1
-- Date            :   12 Dec 2000
-- Modifier        :   Jamil Khatib (khatib@ieee.org)
-- Desccription    :   Created
-- Known bugs      :   
-- To Optimize
-------------------------------------------------------------------------------

library fpu;
use fpu.fpu_pkg.all;

library IEEE;
use IEEE.std_logic_1164.all;

entity encode_ent is
  
  port (
    clk        : in  std_logic;         -- system clock
    rst        : in  std_logic;         -- system reset
    RoundedRes : in  FPinternal_typ;    -- Rounded input result
    Result     : out FPNUMBER_typ;      -- IEEE encoded format
    ResType    : in  SPECIALNO_typ);    -- Result type

end encode_ent;

architecture encode_beh of encode_ent is

begin  -- encode_beh

  -- purpose: Encoder
  -- type   : sequential
  -- inputs : clk, rst
  -- outputs: 
  encode_proc: process (clk, rst)
  begin  -- process encode_proc
    if rst = '0' then                   -- asynchronous reset (active low)
      
       Result.exp <= (others => '0');
       Result.fract <= (others => '0');
       Result.sign <= '0';
       
    elsif clk'event and clk = '1' then  -- rising clock edge
       Result.sign <= RoundedRes.sign;
       
     if ResType.SNAN = '1' or ResType.QNAN = '1'  then

       Result.exp <= (others => '1');
      
       Result.fract <= (ResType.SNAN , others => '1');
         
     elsif ResType.inf = '1' then
       Result.exp <= (others => '1');
      
       Result.fract <= (others => '0');
       
     else
      Result.exp <= RoundedRes.exp(RoundedRes.exp'length-2 downto 0);
      Result.fract <= RoundedRes.fract(RoundedRes.fract'length -3 downto 0);
       
      end if; 
    end if;
  end process encode_proc;

end encode_beh;
