-------------------------------------------------------------------------------
-- Title      :  fpu components package
-- Project    :  Floating-Point Unit core
-------------------------------------------------------------------------------
-- File        : components_pkg.vhd
-- Author      : Jamil Khatib  (khatib@ieee.org)
-- Organization: OpenIPCore Project
-- Created     : 2000/12/12
-- Last update : 2000/12/12
-- Platform    : 
-- Simulators  : Modelsim 5.3XE/Windows98
-- Synthesizers: Leonardo/WindowsNT
-- Target      : 
-- Dependency  : ieee.std_logic_1164
--				 utility.tools_pkg
--               fpu.fpu_pkg
-------------------------------------------------------------------------------
-- Description: FPU Decode: extracts the special numbers and the hidden bit
-------------------------------------------------------------------------------
-- Copyright (c) 2000 Jamil Khatib
-- 
-- This VHDL design file is an open design; you can redistribute it and/or
-- modify it and/or implement it after contacting the author
-- You can check the draft license at
-- http://www.opencores.org/OIPC/license.shtml

-------------------------------------------------------------------------------
-- Revisions  :
-- Revision Number :   1
-- Version         :   0.1
-- Date            :   3rd Nov 2000
-- Modifier        :   Jamil Khatib (khatib@ieee.org)
-- Desccription    :   Created
-- Bugs            :
-------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;

library utility;
use utility.tools_pkg.all;

library fpu;
use fpu.fpu_pkg.all;

package components_pkg is
-------------------------------------------------------------------------------
component decode_ent
   port (
    InNumber  : in  FPNUMBER_typ;       -- FP number input
    OutNumber : out FPinternal_typ;     -- decoded fp number
    clk       : in  std_logic;          -- system clock
    rst       : in  std_logic;          -- system reset
    NoType    : out SPECIALNO_typ );    -- Special no. result

  end component;  
-------------------------------------------------------------------------------
component cal_unit_ent
   port (
    clk       : in  std_logic;          -- system clock
    rst       : in  std_logic;          -- system reset
    Operand1  : in  FPinternal_typ;     -- Operand 1
    Operand2  : in  FPinternal_typ;     -- Operand 2
    NoType1   : in  SPECIALNO_typ;      -- No. 1 type
    NoType2   : in  SPECIALNO_typ;      -- No. 2 type
    ResType   : out SPECIALNO_typ;      -- Result Special no. type
    Result    : out FPRESULT_typ;       -- Result
    load      : in  std_logic;          -- Load new operands
    done      : out std_logic;          -- calculations done
    Operation : in  std_logic_vector(OPERATIONS_WIDTH-1 downto 0));  -- Operation
end component;
-------------------------------------------------------------------------------
component encode_ent
   port (
    clk        : in  std_logic;         -- system clock
    rst        : in  std_logic;         -- system reset
    RoundedRes : in  FPinternal_typ;    -- Rounded input result
    Result     : out FPNUMBER_typ;      -- IEEE encoded format
    ResType    : in  SPECIALNO_typ);    -- Result type
end component;
-------------------------------------------------------------------------------
component rndnorm_ent
    port (
    clk         : in  std_logic;        -- system clock
    rst         : in  std_logic;        -- system reset
    roundmode   : in  std_logic_vector(1 downto 0);  -- Selected Round mode
    ResIn       : in  FPRESULT_typ;     -- input reseult
    Inexact_exp : out std_logic;        -- Inexact exception signal

    Result : out FPinternal_typ);       -- result in internal format
end component;
-------------------------------------------------------------------------------
component excp_gen_ent
    port (
    clk        : in  std_logic;         -- System clock
    rst        : in  std_logic;         -- System Reset
    inexact    : in  std_logic;         -- Inexact result
    DivZero : in std_logic;             -- Divided by zero
    ResType    : in  SPECIALNO_typ;     -- Result Type
    Result     : in  FPinternal_typ;    -- Result no.
    Exceptions : out EXCEPTION_typ);    -- Exceptions

end component;
-------------------------------------------------------------------------------
component addsub_ent
   port (
    Operand1  : in  FPinternal_typ;     -- Operand 1
    Operand2  : in  FPinternal_typ;     -- Operand2
    NoType1   : in  SPECIALNO_typ;      -- No.1 Type
    NoType2   : in  SPECIALNO_typ;      -- No. 2 Type
    Result    : out FPRESULT_typ;       -- Result no.
    Operation : in  std_logic;          -- Operation '1':Subtract / '0':Add 
    clk       : in  std_logic;          -- System clock
    rst       : in  std_logic;          -- System Reset
    ResType   : out SPECIALNO_typ);     -- Result special no. detection
end component;
-------------------------------------------------------------------------------
component fpu_ent

  generic (
    FP_PRECISION : integer := SINGLE_PRECISION);  -- FPU precision

  port (
    Operand1   : in  FPNUMBER_typ;      -- Operand 1
    Operand2   : in  FPNUMBER_typ;      -- Operand 2
    clk        : in  std_logic;         -- system clock
    rst        : in  std_logic;         -- system reset
    Round_Mode : in  std_logic_vector(1 downto 0);  -- Round mode
    Result     : out FPNUMBER_typ;      -- Result
    Exceptions : out EXCEPTION_typ;     -- FPU exceptions
    conditions : out CONDITIONS_typ;    -- FP operation conditions
    load       : in  std_logic;         -- Load new operands
    done       : out std_logic;         -- calculations done
    Operation  : in  std_logic_vector(OPERATIONS_WIDTH-1 downto 0));  -- Operation

end component;

end components_pkg;
