-------------------------------------------------------------------------------
-- Title      :  FPU test bench package
-- Project    :  Floating-Point Unit core
-------------------------------------------------------------------------------
-- File        : Fpu_tb_pkg.vhd
-- Author      : Jamil Khatib  (khatib@ieee.org)
-- Organization: OpenIPCore Project
-- Created     : 2000/12/18
-- Last update: 2001/01/27
-- Platform    : 
-- Simulators  : Modelsim 5.3XE/Windows98
-- Synthesizers: 
-- Target      : 
-- Dependency  : ieee.std_logic_1164
--                           fpu.fpu_pkg.all;

-------------------------------------------------------------------------------
-- Description: FPU test bench package
-------------------------------------------------------------------------------
-- Copyright (c) 2000 Jamil Khatib
-- 
-- This VHDL design file is an open design; you can redistribute it and/or
-- modify it and/or implement it after contacting the author
-- You can check the draft license at
-- http://www.opencores.org/OIPC/license.shtml

-------------------------------------------------------------------------------
-- Revisions  :
-- Revision Number :   1
-- Version         :   0.1
-- Date            :   18 Dec 2000
-- Modifier        :   Jamil Khatib (khatib@ieee.org)
-- Desccription    :   Created
-- Known bugs      :   
-- To Optimize
-------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;

library fpu;
use fpu.fpu_pkg.all;

package fpu_tb_pkg is

  type FPUTask_typ is record                        -- FPU task
                        Op1        : FPNUMBER_typ;  -- Operand 1
                        Op2        : FPNUMBER_typ;  -- Operand 2
                        Round_Mode : std_logic_vector(3 downto 0);
                                                    -- Round Mode
                        Operation  : std_logic_vector(3 downto 0);
                                                    -- FPU Operation
                      end record;

  type FPUTaskResult_typ is record                         -- FPU task result
                              Result     : FPNUMBER_typ;   -- Operation result
                              Exceptions : EXCEPTION_typ;  -- Exceptions
                              conditions : CONDITIONS_typ;
                                                           -- FP Operation Condition
                            end record;

-------------------------------------------------------------------------------
  component Fpu_client_tb_ent
    generic (
      LogFile    :       string;
      StimFile   :       string);
    port (
      FPUTask    : out   FPUTask_typ;
      EOT        : in    std_logic;
      Result     : in    FPUTaskResult_typ);
  end component;
-------------------------------------------------------------------------------
  component fpu_server_tb_ent
    port (
      FPUTask    : in    FPUTask_typ;
      EOT        : inout std_logic;
      TaskResult : out   FPUTaskResult_typ);
  end component;

end fpu_tb_pkg;
-------------------------------------------------


